@@ -11,7 +11,7 @@
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
@@ -27,15 +27,8 @@
 
 G_BEGIN_DECLS
 
-/* We need to do this with a version check as this header gets installed.
- *
- * DEPRECATED in favour of G_PARAM_STATIC_STRINGS
- **/
-#if GLIB_CHECK_VERSION(2,7,0)
-#define GSF_PARAM_STATIC (G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB)
-#else
-#define GSF_PARAM_STATIC 0
-#endif
+/* kept for compatibility reasons */
+#define GSF_PARAM_STATIC G_PARAM_STATIC_STRINGS
 
 /*************************************************************************/
 
@@ -68,11 +61,11 @@ prefix ## _get_type (void)						\
 
 /**
  * GSF_CLASS:
- * @name: (string) Name of the class.
- * @prefix: (string) Prefix designating the namespace to be used for
+ * @name: Name of the class.
+ * @prefix: Symbol prefix designating the namespace to be used for
  * implementing the class.
- * @class_init: (#GClassInitFunc) Initialisation function for the class.
- * @instance_init: (#GInstanceInitFunc) Initialisation (constructor) function
+ * @class_init: Initialisation function of type #GClassInitFunc for the class.
+ * @instance_init: Initialisation function of type #GInstanceInitFunc
  * for an instance of the class.
  * @parent: Parent class to this class.
  *
